#version 150

uniform int colorStandard;
uniform int deepColor;
uniform sampler2D s_texture_y;
uniform sampler2D s_texture_u;
uniform sampler2D s_texture_v;
in highp vec2 v_texcoord;
out vec4 fragColour;

#define deepLimit1 (16.0/255.0)
#define deepLimit2 (255.0/219.0)

void main() {
    
    highp float y = texture(s_texture_y, v_texcoord).r;
    highp float u = texture(s_texture_u, v_texcoord).r - 0.5;
    highp float v = texture(s_texture_v, v_texcoord).r - 0.5;
    highp float r, g, b;
    
    // BT.601, which is the standard for SDTV is provided as a reference
    if (colorStandard == 601) {
        r = y + 1.13983 * v;
        g = y - 0.39465 * u - 0.58060 * v;
        b = y + 2.03211 * u;
    }
    // Using BT.709 which is the standard for HDTV
    else if (colorStandard == 709) {
        r = y + 1.28033 * v;
        g = y - 0.21482 * u - 0.38059 * v;
        b = y + 2.12798 * u;
    }
    // ITU-R ?
    else {
        r = y + 1.402 * v;
        g = y - 0.344 * u - 0.714 * v;
        b = y + 1.772 * u;
    }
    
    fragColour = vec4(r, g, b, 1.0);
    
    if (deepColor == 1) {
        fragColour -= deepLimit1;
        fragColour *= deepLimit2;
    }
}